# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class EligibilityState(str, Enum):
    """
    EligibilityState
    """

    """
    allowed enum values
    """
    PROCESSING = 'processing'
    COMPLETED = 'completed'
    ERROR = 'error'

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityState:
        """Create an instance of EligibilityState from a JSON string"""
        return EligibilityState(json.loads(json_str))





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from cardscan_client.models.eligibility_api_response import EligibilityApiResponse
from cardscan_client.models.response_metadata import ResponseMetadata

class ListEligibility200Response(BaseModel):
    """
    ListEligibility200Response
    """
    eligibility_requests: conlist(EligibilityApiResponse) = Field(...)
    response_metadata: ResponseMetadata = Field(...)
    __properties = ["eligibility_requests", "response_metadata"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> ListEligibility200Response:
        """Create an instance of ListEligibility200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in eligibility_requests (list)
        _items = []
        if self.eligibility_requests:
            for _item in self.eligibility_requests:
                if _item:
                    _items.append(_item.to_dict())
            _dict['eligibility_requests'] = _items
        # override the default output from pydantic by calling `to_dict()` of response_metadata
        if self.response_metadata:
            _dict['response_metadata'] = self.response_metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ListEligibility200Response:
        """Create an instance of ListEligibility200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ListEligibility200Response.parse_obj(obj)

        _obj = ListEligibility200Response.parse_obj({
            "eligibility_requests": [EligibilityApiResponse.from_dict(_item) for _item in obj.get("eligibility_requests")] if obj.get("eligibility_requests") is not None else None,
            "response_metadata": ResponseMetadata.from_dict(obj.get("response_metadata")) if obj.get("response_metadata") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from cardscan_client.models.card_api_response_details import CardApiResponseDetails
from cardscan_client.models.card_api_response_images import CardApiResponseImages
from cardscan_client.models.card_state import CardState
from cardscan_client.models.model_error import ModelError

class CardApiResponse(BaseModel):
    """
    CardApiResponse
    """
    card_id: StrictStr = Field(...)
    state: CardState = Field(...)
    created_at: datetime = Field(default=..., description="The timestamp when the eligibility response was created.")
    error: Optional[ModelError] = None
    images: Optional[CardApiResponseImages] = None
    deleted: StrictBool = Field(...)
    details: Optional[CardApiResponseDetails] = None
    __properties = ["card_id", "state", "created_at", "error", "images", "deleted", "details"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> CardApiResponse:
        """Create an instance of CardApiResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of error
        if self.error:
            _dict['error'] = self.error.to_dict()
        # override the default output from pydantic by calling `to_dict()` of images
        if self.images:
            _dict['images'] = self.images.to_dict()
        # override the default output from pydantic by calling `to_dict()` of details
        if self.details:
            _dict['details'] = self.details.to_dict()
        # set to None if images (nullable) is None
        # and __fields_set__ contains the field
        if self.images is None and "images" in self.__fields_set__:
            _dict['images'] = None

        # set to None if details (nullable) is None
        # and __fields_set__ contains the field
        if self.details is None and "details" in self.__fields_set__:
            _dict['details'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardApiResponse:
        """Create an instance of CardApiResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CardApiResponse.parse_obj(obj)

        _obj = CardApiResponse.parse_obj({
            "card_id": obj.get("card_id"),
            "state": obj.get("state"),
            "created_at": obj.get("created_at"),
            "error": ModelError.from_dict(obj.get("error")) if obj.get("error") is not None else None,
            "images": CardApiResponseImages.from_dict(obj.get("images")) if obj.get("images") is not None else None,
            "deleted": obj.get("deleted"),
            "details": CardApiResponseDetails.from_dict(obj.get("details")) if obj.get("details") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class UploadParameters(BaseModel):
    """
    UploadParameters
    """
    content_type: StrictStr = Field(default=..., alias="Content-Type", description="The content type of the file")
    content_disposition: StrictStr = Field(default=..., alias="Content-Disposition", description="The content disposition of the file")
    x_amz_meta_cardscan_account_id: StrictStr = Field(default=..., alias="x-amz-meta-cardscan-account-id", description="The account ID")
    x_amz_meta_cardscan_card_id: StrictStr = Field(default=..., alias="x-amz-meta-cardscan-card-id", description="The card ID")
    x_amz_meta_cardscan_scan_id: StrictStr = Field(default=..., alias="x-amz-meta-cardscan-scan-id", description="The scan ID")
    x_amz_meta_cardscan_user_id: Optional[StrictStr] = Field(default=None, alias="x-amz-meta-cardscan-user-id", description="The user ID")
    x_amz_meta_cardscan_developer_user_id: Optional[StrictStr] = Field(default=None, alias="x-amz-meta-cardscan-developer-user-id", description="The developer user ID")
    key: StrictStr = Field(default=..., description="The key of the file")
    x_amz_algorithm: StrictStr = Field(default=..., alias="x-amz-algorithm", description="The algorithm used to sign the request")
    x_amz_credential: StrictStr = Field(default=..., alias="x-amz-credential", description="The credential used to sign the request")
    x_amz_date: StrictStr = Field(default=..., alias="x-amz-date", description="The date of the request")
    x_amz_security_token: StrictStr = Field(default=..., alias="x-amz-security-token", description="The security token used to sign the request")
    policy: StrictStr = Field(default=..., description="The policy used to sign the request")
    x_amz_signature: StrictStr = Field(default=..., alias="x-amz-signature", description="The signature used to sign the request")
    __properties = ["Content-Type", "Content-Disposition", "x-amz-meta-cardscan-account-id", "x-amz-meta-cardscan-card-id", "x-amz-meta-cardscan-scan-id", "x-amz-meta-cardscan-user-id", "x-amz-meta-cardscan-developer-user-id", "key", "x-amz-algorithm", "x-amz-credential", "x-amz-date", "x-amz-security-token", "policy", "x-amz-signature"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> UploadParameters:
        """Create an instance of UploadParameters from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UploadParameters:
        """Create an instance of UploadParameters from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UploadParameters.parse_obj(obj)

        _obj = UploadParameters.parse_obj({
            "content_type": obj.get("Content-Type"),
            "content_disposition": obj.get("Content-Disposition"),
            "x_amz_meta_cardscan_account_id": obj.get("x-amz-meta-cardscan-account-id"),
            "x_amz_meta_cardscan_card_id": obj.get("x-amz-meta-cardscan-card-id"),
            "x_amz_meta_cardscan_scan_id": obj.get("x-amz-meta-cardscan-scan-id"),
            "x_amz_meta_cardscan_user_id": obj.get("x-amz-meta-cardscan-user-id"),
            "x_amz_meta_cardscan_developer_user_id": obj.get("x-amz-meta-cardscan-developer-user-id"),
            "key": obj.get("key"),
            "x_amz_algorithm": obj.get("x-amz-algorithm"),
            "x_amz_credential": obj.get("x-amz-credential"),
            "x_amz_date": obj.get("x-amz-date"),
            "x_amz_security_token": obj.get("x-amz-security-token"),
            "policy": obj.get("policy"),
            "x_amz_signature": obj.get("x-amz-signature")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictStr, validator
from cardscan_client.models.eligibility_api_response_eligibility_request import EligibilityApiResponseEligibilityRequest
from cardscan_client.models.eligibility_summarized_response import EligibilitySummarizedResponse
from cardscan_client.models.model_error import ModelError

class EligibilityApiResponse(BaseModel):
    """
    EligibilityApiResponse
    """
    eligibility_id: StrictStr = Field(default=..., description="The ID of the eligibility record.")
    state: StrictStr = Field(default=..., description="The state of the eligibility record.")
    card_id: StrictStr = Field(default=..., description="The ID of the card.")
    eligibility_request: Optional[EligibilityApiResponseEligibilityRequest] = None
    eligibility_response: Optional[Dict[str, Any]] = Field(default=None, description="The eligibility raw response.")
    eligibility_summarized_response: Optional[EligibilitySummarizedResponse] = None
    error: Optional[ModelError] = None
    created_at: datetime = Field(default=..., description="The timestamp when the eligibility record was created.")
    __properties = ["eligibility_id", "state", "card_id", "eligibility_request", "eligibility_response", "eligibility_summarized_response", "error", "created_at"]

    @validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('completed', 'processing', 'error'):
            raise ValueError("must be one of enum values ('completed', 'processing', 'error')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityApiResponse:
        """Create an instance of EligibilityApiResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of eligibility_request
        if self.eligibility_request:
            _dict['eligibility_request'] = self.eligibility_request.to_dict()
        # override the default output from pydantic by calling `to_dict()` of eligibility_summarized_response
        if self.eligibility_summarized_response:
            _dict['eligibility_summarized_response'] = self.eligibility_summarized_response.to_dict()
        # override the default output from pydantic by calling `to_dict()` of error
        if self.error:
            _dict['error'] = self.error.to_dict()
        # set to None if eligibility_response (nullable) is None
        # and __fields_set__ contains the field
        if self.eligibility_response is None and "eligibility_response" in self.__fields_set__:
            _dict['eligibility_response'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EligibilityApiResponse:
        """Create an instance of EligibilityApiResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EligibilityApiResponse.parse_obj(obj)

        _obj = EligibilityApiResponse.parse_obj({
            "eligibility_id": obj.get("eligibility_id"),
            "state": obj.get("state"),
            "card_id": obj.get("card_id"),
            "eligibility_request": EligibilityApiResponseEligibilityRequest.from_dict(obj.get("eligibility_request")) if obj.get("eligibility_request") is not None else None,
            "eligibility_response": obj.get("eligibility_response"),
            "eligibility_summarized_response": EligibilitySummarizedResponse.from_dict(obj.get("eligibility_summarized_response")) if obj.get("eligibility_summarized_response") is not None else None,
            "error": ModelError.from_dict(obj.get("error")) if obj.get("error") is not None else None,
            "created_at": obj.get("created_at")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, conlist
from cardscan_client.models.match_score import MatchScore

class CardApiResponseDetails(BaseModel):
    """
    CardApiResponseDetails
    """
    group_number: Optional[MatchScore] = None
    member_number: Optional[MatchScore] = None
    payer_name: Optional[MatchScore] = None
    rx_bin: Optional[MatchScore] = None
    rx_pcn: Optional[MatchScore] = None
    member_name: Optional[MatchScore] = None
    dependent_names: Optional[conlist(MatchScore)] = None
    plan_name: Optional[MatchScore] = None
    plan_id: Optional[MatchScore] = None
    card_specific_id: Optional[MatchScore] = None
    client_name: Optional[MatchScore] = None
    payer_id: Optional[MatchScore] = None
    plan_details: Optional[MatchScore] = None
    rx_id: Optional[MatchScore] = None
    rx_issuer: Optional[MatchScore] = None
    rx_plan: Optional[MatchScore] = None
    start_date: Optional[MatchScore] = None
    employer: Optional[MatchScore] = None
    medicare_medicaid_id: Optional[MatchScore] = None
    member_dob: Optional[MatchScore] = None
    member_gender: Optional[MatchScore] = None
    member_id_prefix: Optional[MatchScore] = None
    member_id_suffix: Optional[MatchScore] = None
    part_a_effective_date: Optional[MatchScore] = None
    part_b_effective_date: Optional[MatchScore] = None
    pharmacy_benefit_manager: Optional[MatchScore] = None
    plan_type: Optional[MatchScore] = None
    __properties = ["group_number", "member_number", "payer_name", "rx_bin", "rx_pcn", "member_name", "dependent_names", "plan_name", "plan_id", "card_specific_id", "client_name", "payer_id", "plan_details", "rx_id", "rx_issuer", "rx_plan", "start_date", "employer", "medicare_medicaid_id", "member_dob", "member_gender", "member_id_prefix", "member_id_suffix", "part_a_effective_date", "part_b_effective_date", "pharmacy_benefit_manager", "plan_type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> CardApiResponseDetails:
        """Create an instance of CardApiResponseDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of group_number
        if self.group_number:
            _dict['group_number'] = self.group_number.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_number
        if self.member_number:
            _dict['member_number'] = self.member_number.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payer_name
        if self.payer_name:
            _dict['payer_name'] = self.payer_name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rx_bin
        if self.rx_bin:
            _dict['rx_bin'] = self.rx_bin.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rx_pcn
        if self.rx_pcn:
            _dict['rx_pcn'] = self.rx_pcn.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_name
        if self.member_name:
            _dict['member_name'] = self.member_name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in dependent_names (list)
        _items = []
        if self.dependent_names:
            for _item in self.dependent_names:
                if _item:
                    _items.append(_item.to_dict())
            _dict['dependent_names'] = _items
        # override the default output from pydantic by calling `to_dict()` of plan_name
        if self.plan_name:
            _dict['plan_name'] = self.plan_name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plan_id
        if self.plan_id:
            _dict['plan_id'] = self.plan_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_specific_id
        if self.card_specific_id:
            _dict['card_specific_id'] = self.card_specific_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of client_name
        if self.client_name:
            _dict['client_name'] = self.client_name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payer_id
        if self.payer_id:
            _dict['payer_id'] = self.payer_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plan_details
        if self.plan_details:
            _dict['plan_details'] = self.plan_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rx_id
        if self.rx_id:
            _dict['rx_id'] = self.rx_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rx_issuer
        if self.rx_issuer:
            _dict['rx_issuer'] = self.rx_issuer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rx_plan
        if self.rx_plan:
            _dict['rx_plan'] = self.rx_plan.to_dict()
        # override the default output from pydantic by calling `to_dict()` of start_date
        if self.start_date:
            _dict['start_date'] = self.start_date.to_dict()
        # override the default output from pydantic by calling `to_dict()` of employer
        if self.employer:
            _dict['employer'] = self.employer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of medicare_medicaid_id
        if self.medicare_medicaid_id:
            _dict['medicare_medicaid_id'] = self.medicare_medicaid_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_dob
        if self.member_dob:
            _dict['member_dob'] = self.member_dob.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_gender
        if self.member_gender:
            _dict['member_gender'] = self.member_gender.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_id_prefix
        if self.member_id_prefix:
            _dict['member_id_prefix'] = self.member_id_prefix.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_id_suffix
        if self.member_id_suffix:
            _dict['member_id_suffix'] = self.member_id_suffix.to_dict()
        # override the default output from pydantic by calling `to_dict()` of part_a_effective_date
        if self.part_a_effective_date:
            _dict['part_a_effective_date'] = self.part_a_effective_date.to_dict()
        # override the default output from pydantic by calling `to_dict()` of part_b_effective_date
        if self.part_b_effective_date:
            _dict['part_b_effective_date'] = self.part_b_effective_date.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pharmacy_benefit_manager
        if self.pharmacy_benefit_manager:
            _dict['pharmacy_benefit_manager'] = self.pharmacy_benefit_manager.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plan_type
        if self.plan_type:
            _dict['plan_type'] = self.plan_type.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardApiResponseDetails:
        """Create an instance of CardApiResponseDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CardApiResponseDetails.parse_obj(obj)

        _obj = CardApiResponseDetails.parse_obj({
            "group_number": MatchScore.from_dict(obj.get("group_number")) if obj.get("group_number") is not None else None,
            "member_number": MatchScore.from_dict(obj.get("member_number")) if obj.get("member_number") is not None else None,
            "payer_name": MatchScore.from_dict(obj.get("payer_name")) if obj.get("payer_name") is not None else None,
            "rx_bin": MatchScore.from_dict(obj.get("rx_bin")) if obj.get("rx_bin") is not None else None,
            "rx_pcn": MatchScore.from_dict(obj.get("rx_pcn")) if obj.get("rx_pcn") is not None else None,
            "member_name": MatchScore.from_dict(obj.get("member_name")) if obj.get("member_name") is not None else None,
            "dependent_names": [MatchScore.from_dict(_item) for _item in obj.get("dependent_names")] if obj.get("dependent_names") is not None else None,
            "plan_name": MatchScore.from_dict(obj.get("plan_name")) if obj.get("plan_name") is not None else None,
            "plan_id": MatchScore.from_dict(obj.get("plan_id")) if obj.get("plan_id") is not None else None,
            "card_specific_id": MatchScore.from_dict(obj.get("card_specific_id")) if obj.get("card_specific_id") is not None else None,
            "client_name": MatchScore.from_dict(obj.get("client_name")) if obj.get("client_name") is not None else None,
            "payer_id": MatchScore.from_dict(obj.get("payer_id")) if obj.get("payer_id") is not None else None,
            "plan_details": MatchScore.from_dict(obj.get("plan_details")) if obj.get("plan_details") is not None else None,
            "rx_id": MatchScore.from_dict(obj.get("rx_id")) if obj.get("rx_id") is not None else None,
            "rx_issuer": MatchScore.from_dict(obj.get("rx_issuer")) if obj.get("rx_issuer") is not None else None,
            "rx_plan": MatchScore.from_dict(obj.get("rx_plan")) if obj.get("rx_plan") is not None else None,
            "start_date": MatchScore.from_dict(obj.get("start_date")) if obj.get("start_date") is not None else None,
            "employer": MatchScore.from_dict(obj.get("employer")) if obj.get("employer") is not None else None,
            "medicare_medicaid_id": MatchScore.from_dict(obj.get("medicare_medicaid_id")) if obj.get("medicare_medicaid_id") is not None else None,
            "member_dob": MatchScore.from_dict(obj.get("member_dob")) if obj.get("member_dob") is not None else None,
            "member_gender": MatchScore.from_dict(obj.get("member_gender")) if obj.get("member_gender") is not None else None,
            "member_id_prefix": MatchScore.from_dict(obj.get("member_id_prefix")) if obj.get("member_id_prefix") is not None else None,
            "member_id_suffix": MatchScore.from_dict(obj.get("member_id_suffix")) if obj.get("member_id_suffix") is not None else None,
            "part_a_effective_date": MatchScore.from_dict(obj.get("part_a_effective_date")) if obj.get("part_a_effective_date") is not None else None,
            "part_b_effective_date": MatchScore.from_dict(obj.get("part_b_effective_date")) if obj.get("part_b_effective_date") is not None else None,
            "pharmacy_benefit_manager": MatchScore.from_dict(obj.get("pharmacy_benefit_manager")) if obj.get("pharmacy_benefit_manager") is not None else None,
            "plan_type": MatchScore.from_dict(obj.get("plan_type")) if obj.get("plan_type") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, constr

class ProviderDto(BaseModel):
    """
    ProviderDto
    """
    first_name: Optional[constr(strict=True, max_length=35, min_length=1)] = Field(default=None, alias="firstName", description="Loop: 2100B Segment: MN1, Element: NM104, Notes: NM101=PR when providerType='payer' && payerId is present otherwise 1P for Provider, NM102=1 Person, firstName 1-35 alphanumeric characters ")
    last_name: Optional[constr(strict=True, max_length=60, min_length=1)] = Field(default=None, alias="lastName", description="Loop: 2100B Segment: MN1, Element: NM103, Notes: NM101=PR when providerType='payer' && payerId is present otherwise 1P for Provider, NM102=1 Person, lastName 1-60 alphanumeric characters ")
    npi: constr(strict=True, max_length=80, min_length=1) = Field(default=..., description="Loop: 2100B Segment: MN1, Element: NM109, Notes: NM108=XX Centers for Medicare and Medicaid Services National Provider Identifier 2-80 alphanumeric characters ")
    organization_name: Optional[constr(strict=True, max_length=60, min_length=0)] = Field(default=None, alias="organizationName")
    __properties = ["firstName", "lastName", "npi", "organizationName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> ProviderDto:
        """Create an instance of ProviderDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProviderDto:
        """Create an instance of ProviderDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ProviderDto.parse_obj(obj)

        _obj = ProviderDto.parse_obj({
            "first_name": obj.get("firstName"),
            "last_name": obj.get("lastName"),
            "npi": obj.get("npi"),
            "organization_name": obj.get("organizationName")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class PlanDetails(BaseModel):
    """
    PlanDetails
    """
    plan_number: Optional[StrictStr] = Field(default=None, description="The plan number.")
    group_name: Optional[StrictStr] = Field(default=None, description="The name of the group associated with the plan.")
    group_number: Optional[StrictStr] = Field(default=None, description="The group number.")
    plan_start_date: Optional[date] = Field(default=None, description="The start date of the plan.")
    plan_end_date: Optional[date] = Field(default=None, description="The end date of the plan.")
    plan_eligibility_start_date: Optional[date] = Field(default=None, description="The eligibility start date of the plan.")
    plan_eligibility_end_date: Optional[date] = Field(default=None, description="The eligibility end date of the plan.")
    plan_name: Optional[StrictStr] = Field(default=None, description="The name of the plan.")
    plan_active: Optional[StrictBool] = Field(default=None, description="Indicates whether the plan is active.")
    __properties = ["plan_number", "group_name", "group_number", "plan_start_date", "plan_end_date", "plan_eligibility_start_date", "plan_eligibility_end_date", "plan_name", "plan_active"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> PlanDetails:
        """Create an instance of PlanDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PlanDetails:
        """Create an instance of PlanDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PlanDetails.parse_obj(obj)

        _obj = PlanDetails.parse_obj({
            "plan_number": obj.get("plan_number"),
            "group_name": obj.get("group_name"),
            "group_number": obj.get("group_number"),
            "plan_start_date": obj.get("plan_start_date"),
            "plan_end_date": obj.get("plan_end_date"),
            "plan_eligibility_start_date": obj.get("plan_eligibility_start_date"),
            "plan_eligibility_end_date": obj.get("plan_eligibility_end_date"),
            "plan_name": obj.get("plan_name"),
            "plan_active": obj.get("plan_active")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from cardscan_client.models.co_insurance import CoInsurance
from cardscan_client.models.co_payment import CoPayment
from cardscan_client.models.deductible import Deductible
from cardscan_client.models.oop import OOP

class CoverageSummary(BaseModel):
    """
    CoverageSummary
    """
    individual_deductible_in_network: Optional[Deductible] = None
    individual_deductible_out_network: Optional[Deductible] = None
    individual_oop_in_network: Optional[OOP] = None
    individual_oop_out_network: Optional[OOP] = None
    family_deductible_in_network: Optional[Deductible] = None
    family_deductible_out_network: Optional[Deductible] = None
    family_oop_in_network: Optional[OOP] = None
    family_oop_out_network: Optional[OOP] = None
    co_insurance_in_network: Optional[CoInsurance] = None
    co_insurance_out_network: Optional[CoInsurance] = None
    co_payment_out_network: Optional[CoPayment] = None
    co_payment_in_network: Optional[CoPayment] = None
    __properties = ["individual_deductible_in_network", "individual_deductible_out_network", "individual_oop_in_network", "individual_oop_out_network", "family_deductible_in_network", "family_deductible_out_network", "family_oop_in_network", "family_oop_out_network", "co_insurance_in_network", "co_insurance_out_network", "co_payment_out_network", "co_payment_in_network"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> CoverageSummary:
        """Create an instance of CoverageSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of individual_deductible_in_network
        if self.individual_deductible_in_network:
            _dict['individual_deductible_in_network'] = self.individual_deductible_in_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of individual_deductible_out_network
        if self.individual_deductible_out_network:
            _dict['individual_deductible_out_network'] = self.individual_deductible_out_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of individual_oop_in_network
        if self.individual_oop_in_network:
            _dict['individual_oop_in_network'] = self.individual_oop_in_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of individual_oop_out_network
        if self.individual_oop_out_network:
            _dict['individual_oop_out_network'] = self.individual_oop_out_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of family_deductible_in_network
        if self.family_deductible_in_network:
            _dict['family_deductible_in_network'] = self.family_deductible_in_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of family_deductible_out_network
        if self.family_deductible_out_network:
            _dict['family_deductible_out_network'] = self.family_deductible_out_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of family_oop_in_network
        if self.family_oop_in_network:
            _dict['family_oop_in_network'] = self.family_oop_in_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of family_oop_out_network
        if self.family_oop_out_network:
            _dict['family_oop_out_network'] = self.family_oop_out_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of co_insurance_in_network
        if self.co_insurance_in_network:
            _dict['co_insurance_in_network'] = self.co_insurance_in_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of co_insurance_out_network
        if self.co_insurance_out_network:
            _dict['co_insurance_out_network'] = self.co_insurance_out_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of co_payment_out_network
        if self.co_payment_out_network:
            _dict['co_payment_out_network'] = self.co_payment_out_network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of co_payment_in_network
        if self.co_payment_in_network:
            _dict['co_payment_in_network'] = self.co_payment_in_network.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CoverageSummary:
        """Create an instance of CoverageSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CoverageSummary.parse_obj(obj)

        _obj = CoverageSummary.parse_obj({
            "individual_deductible_in_network": Deductible.from_dict(obj.get("individual_deductible_in_network")) if obj.get("individual_deductible_in_network") is not None else None,
            "individual_deductible_out_network": Deductible.from_dict(obj.get("individual_deductible_out_network")) if obj.get("individual_deductible_out_network") is not None else None,
            "individual_oop_in_network": OOP.from_dict(obj.get("individual_oop_in_network")) if obj.get("individual_oop_in_network") is not None else None,
            "individual_oop_out_network": OOP.from_dict(obj.get("individual_oop_out_network")) if obj.get("individual_oop_out_network") is not None else None,
            "family_deductible_in_network": Deductible.from_dict(obj.get("family_deductible_in_network")) if obj.get("family_deductible_in_network") is not None else None,
            "family_deductible_out_network": Deductible.from_dict(obj.get("family_deductible_out_network")) if obj.get("family_deductible_out_network") is not None else None,
            "family_oop_in_network": OOP.from_dict(obj.get("family_oop_in_network")) if obj.get("family_oop_in_network") is not None else None,
            "family_oop_out_network": OOP.from_dict(obj.get("family_oop_out_network")) if obj.get("family_oop_out_network") is not None else None,
            "co_insurance_in_network": CoInsurance.from_dict(obj.get("co_insurance_in_network")) if obj.get("co_insurance_in_network") is not None else None,
            "co_insurance_out_network": CoInsurance.from_dict(obj.get("co_insurance_out_network")) if obj.get("co_insurance_out_network") is not None else None,
            "co_payment_out_network": CoPayment.from_dict(obj.get("co_payment_out_network")) if obj.get("co_payment_out_network") is not None else None,
            "co_payment_in_network": CoPayment.from_dict(obj.get("co_payment_in_network")) if obj.get("co_payment_in_network") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from cardscan_client.models.scan_metadata_camera_capabilities_aspect_ratio import ScanMetadataCameraCapabilitiesAspectRatio

class ScanMetadataCameraCapabilities(BaseModel):
    """
    Camera capabilities  # noqa: E501
    """
    aspect_ratio: Optional[ScanMetadataCameraCapabilitiesAspectRatio] = Field(default=None, alias="aspectRatio")
    device_id: Optional[StrictStr] = Field(default=None, alias="deviceId")
    facing_mode: Optional[conlist(StrictStr)] = Field(default=None, alias="facingMode")
    frame_rate: Optional[ScanMetadataCameraCapabilitiesAspectRatio] = Field(default=None, alias="frameRate")
    group_id: Optional[StrictStr] = Field(default=None, alias="groupId")
    height: Optional[ScanMetadataCameraCapabilitiesAspectRatio] = None
    resize_mode: Optional[conlist(StrictStr)] = Field(default=None, alias="resizeMode")
    width: Optional[ScanMetadataCameraCapabilitiesAspectRatio] = None
    __properties = ["aspectRatio", "deviceId", "facingMode", "frameRate", "groupId", "height", "resizeMode", "width"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> ScanMetadataCameraCapabilities:
        """Create an instance of ScanMetadataCameraCapabilities from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of aspect_ratio
        if self.aspect_ratio:
            _dict['aspectRatio'] = self.aspect_ratio.to_dict()
        # override the default output from pydantic by calling `to_dict()` of frame_rate
        if self.frame_rate:
            _dict['frameRate'] = self.frame_rate.to_dict()
        # override the default output from pydantic by calling `to_dict()` of height
        if self.height:
            _dict['height'] = self.height.to_dict()
        # override the default output from pydantic by calling `to_dict()` of width
        if self.width:
            _dict['width'] = self.width.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ScanMetadataCameraCapabilities:
        """Create an instance of ScanMetadataCameraCapabilities from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ScanMetadataCameraCapabilities.parse_obj(obj)

        _obj = ScanMetadataCameraCapabilities.parse_obj({
            "aspect_ratio": ScanMetadataCameraCapabilitiesAspectRatio.from_dict(obj.get("aspectRatio")) if obj.get("aspectRatio") is not None else None,
            "device_id": obj.get("deviceId"),
            "facing_mode": obj.get("facingMode"),
            "frame_rate": ScanMetadataCameraCapabilitiesAspectRatio.from_dict(obj.get("frameRate")) if obj.get("frameRate") is not None else None,
            "group_id": obj.get("groupId"),
            "height": ScanMetadataCameraCapabilitiesAspectRatio.from_dict(obj.get("height")) if obj.get("height") is not None else None,
            "resize_mode": obj.get("resizeMode"),
            "width": ScanMetadataCameraCapabilitiesAspectRatio.from_dict(obj.get("width")) if obj.get("width") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictStr

class EligibilityApiResponseError(BaseModel):
    """
    Details about any error that occurred during the request. (Only first error)  # noqa: E501
    """
    type: Optional[StrictStr] = Field(default=None, description="The type of error.")
    code: Optional[StrictStr] = Field(default=None, description="The error code.")
    message: Optional[StrictStr] = Field(default=None, description="A message describing the error.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["type", "code", "message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityApiResponseError:
        """Create an instance of EligibilityApiResponseError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EligibilityApiResponseError:
        """Create an instance of EligibilityApiResponseError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EligibilityApiResponseError.parse_obj(obj)

        _obj = EligibilityApiResponseError.parse_obj({
            "type": obj.get("type"),
            "code": obj.get("code"),
            "message": obj.get("message")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CardState(str, Enum):
    """
    CardState
    """

    """
    allowed enum values
    """
    PENDING = 'pending'
    PROCESSING = 'processing'
    FRONTSIDE_PROCESSING = 'frontside_processing'
    FRONTSIDE_FAILED = 'frontside_failed'
    BACKSIDE_PROCESSING = 'backside_processing'
    BACKSIDE_FAILED = 'backside_failed'
    POST_PROCESSING = 'post_processing'
    COMPLETED = 'completed'
    ERROR = 'error'
    UNKNOWN = 'unknown'

    @classmethod
    def from_json(cls, json_str: str) -> CardState:
        """Create an instance of CardState from a JSON string"""
        return CardState(json.loads(json_str))





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

import asyncio
import json
import websockets
import websocket
from contextlib import closing
import time

from cardscan_client.models.card_websocket_event import CardWebsocketEvent
from cardscan_client.models.eligibility_websocket_event import EligibilityWebsocketEvent
from cardscan_client.models.card_state import CardState
from cardscan_client.models.eligibility_state import EligibilityState

from typing_extensions import Annotated
from pydantic import Field, StrictInt, StrictStr, conint

from typing import Any, Dict, Optional

from cardscan_client.models.card_api_response import CardApiResponse
from cardscan_client.models.card_performance200_response import CardPerformance200Response
from cardscan_client.models.create_card_request import CreateCardRequest
from cardscan_client.models.create_eligibility_request import CreateEligibilityRequest
from cardscan_client.models.direct_upload200_response import DirectUpload200Response
from cardscan_client.models.direct_upload_request import DirectUploadRequest
from cardscan_client.models.eligibility_api_response import EligibilityApiResponse
from cardscan_client.models.generate_card_upload_url200_response import GenerateCardUploadUrl200Response
from cardscan_client.models.generate_card_upload_url_request import GenerateCardUploadUrlRequest
from cardscan_client.models.generate_magic_link200_response import GenerateMagicLink200Response
from cardscan_client.models.get_access_token200_response import GetAccessToken200Response
from cardscan_client.models.list_eligibility200_response import ListEligibility200Response
from cardscan_client.models.scan_capture_type import ScanCaptureType
from cardscan_client.models.scan_orientation import ScanOrientation
from cardscan_client.models.search_cards200_response import SearchCards200Response
from cardscan_client.models.validate_magic_link200_response import ValidateMagicLink200Response

from cardscan_client.api_client import ApiClient
from cardscan_client.api_response import ApiResponse
from cardscan_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)

from typing import Optional, Union


class CardScanApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

        token = (
            self.api_client.configuration.access_token
            or self.api_client.configuration.api_key
        )

        self.websocket_url = f"{self.api_client.configuration.websocket_url}?token={token}"

    def full_scan(
        self, front_image_path: str, back_image_path: Optional[str] = None, timeout: int = 60
    ) -> Union[CardApiResponse, None]:
        """Perform a full scan of either the front or both sides of a card.
        :param back_image_path: The path to the back image of the card. (optional)
        :param front_image_path: The path to the front image of the card.
        :param timeout: The maximum time to wait for the scan to complete.
        """
        if not self.websocket_url:
            raise ValueError("This method cannot be called without a websocket URL.")

        response = self.create_card(
            CreateCardRequest(enable_livescan=False, enable_backside_scan=(back_image_path is not None))
        )

        result = None
        with closing(websocket.create_connection(self.websocket_url)) as ws:
            ws.send(json.dumps({"card_id": response.card_id, "action": "register"}))

            # Front image upload and processing
            front_upload_url_response = self.generate_card_upload_url(
                response.card_id, 3600, GenerateCardUploadUrlRequest(orientation=ScanOrientation.FRONT)
            )
            self.upload_image(front_upload_url_response.upload_url, front_upload_url_response.upload_parameters.to_dict(), front_image_path)

            result = self.handle_card_events(ws, [CardState.FRONTSIDE_FAILED, CardState.ERROR], timeout)

            # Check if backside processing is needed
            if back_image_path:
                back_upload_url_response = self.generate_card_upload_url(
                    response.card_id, 3600, GenerateCardUploadUrlRequest(orientation=ScanOrientation.BACK)
                )
                self.upload_image(back_upload_url_response.upload_url, back_upload_url_response.upload_parameters.to_dict(), back_image_path)
                result = self.handle_card_events(ws, [CardState.BACKSIDE_FAILED, CardState.ERROR], timeout)

        if result:
            return self.get_card_by_id(result.card_id)
        return result

    async def full_scan_async(
        self, front_image_path: str, back_image_path: Optional[str] = None, timeout: int = 60
    ) -> Union[CardApiResponse, None]:
        """
        Asynchronously perform a full scan of either the front or both sides of a card.
        :param back_image_path: The path to the back image of the card. (optional)
        :param front_image_path: The path to the front image of the card.
        :param timeout: The maximum time to wait for the scan to complete.
        """

        if not self.websocket_url:
            raise ValueError("This method cannot be called without a websocket URL.")

        response = self.create_card(
            CreateCardRequest(enable_livescan=False, enable_backside_scan=(back_image_path is not None))
        )

        result = None
        async with websockets.connect(self.websocket_url) as ws:
            await ws.send(json.dumps({"card_id": response.card_id, "action": "register"}))

            # Front image upload and processing
            front_upload_url_response = self.generate_card_upload_url(
                response.card_id, 3600, GenerateCardUploadUrlRequest(orientation=ScanOrientation.FRONT)
            )
            self.upload_image(front_upload_url_response.upload_url, front_upload_url_response.upload_parameters.to_dict(), front_image_path)

            result = await self.handle_card_events_async(ws, [CardState.FRONTSIDE_FAILED, CardState.ERROR], timeout=timeout)

            # Check if backside processing is needed
            if back_image_path:
                back_upload_url_response = self.generate_card_upload_url(
                    response.card_id, 3600, GenerateCardUploadUrlRequest(orientation=ScanOrientation.BACK)
                )
                self.upload_image(back_upload_url_response.upload_url, back_upload_url_response.upload_parameters.to_dict(), back_image_path)
                result = await self.handle_card_events_async(ws, [CardState.BACKSIDE_FAILED, CardState.ERROR], timeout=timeout)

        if result:
            return self.get_card_by_id(result.card_id)
        return result

    def upload_image(self, upload_url, upload_params, image_path):
        """Handles image upload."""
        self.api_client.call_api(
            '',
            "POST",
            _host=upload_url,
            post_params=list(upload_params.items()),
            files={"file": image_path},
            header_params={"Content-Type": "multipart/form-data"},
            response_types_map={}
        )

    def handle_card_events(self, ws: websocket.WebSocket, rejection_states, timeout):
        """Handles WebSocket events, including rejection and completion checking."""
        start_time = time.time()
        result = None

        while True:
            if time.time() - start_time > timeout:
                raise TimeoutError("Processing timed out")

            message = ws.recv()
            event = json.loads(message)

            if event['type'] != 'card':
                continue

            if event["state"] in rejection_states:
                raise Exception(f"Process failed: {event.get('error', {}).get('message', 'Unknown error')}")

            if event["state"] == CardState.COMPLETED:
                result = CardWebsocketEvent.from_dict(event)
                break

            if event["state"] == CardState.BACKSIDE_PROCESSING:
                break

        return result

    async def handle_card_events_async(self, ws, rejection_states, timeout):
        """Async version of handling WebSocket events."""
        result = None

        async def receive_messages():
            nonlocal result
            async for message in ws:
                event = json.loads(message)

                if event['type'] != 'card':
                    continue

                if event["state"] in rejection_states:
                    raise Exception(f"Process failed: {event.get('error', {}).get('message', 'Unknown error')}")

                if event["state"] == CardState.COMPLETED:
                    result = CardWebsocketEvent.from_dict(event)
                    break

                if event["state"] == CardState.BACKSIDE_PROCESSING:
                    break

        try:
            await asyncio.wait_for(receive_messages(), timeout)
        except asyncio.TimeoutError:
            raise TimeoutError("Operation timed out while waiting for WebSocket events.")

        return result

    def check_eligibility(
        self, create_eligibility_request: CreateEligibilityRequest, timeout: int = 60
    ) -> Union[EligibilityApiResponse, None]:
        if not self.websocket_url:
            raise ValueError("This method cannot be called without a websocket URL.")

        response = self.create_eligibility(create_eligibility_request)

        result = None

        with closing(websocket.create_connection(self.websocket_url)) as ws:
            ws.send(
                json.dumps({"card_id": response.card_id, "action": "register"})
            )

            start_time = time.time()

            while True:
                if time.time() - start_time > timeout:
                    raise TimeoutError("Eligibility check timed out")

                message = ws.recv()
                event = json.loads(message)

                if event['type'] != 'eligibility':
                    continue

                if event["state"] == EligibilityState.COMPLETED:
                    result = EligibilityWebsocketEvent.from_dict(event)
                    break
                elif event["state"] == EligibilityState.ERROR:
                    raise Exception(f"Eligibility check failed: {event['error']}")

        if result:
            eligibility = self.get_eligibility_by_id(result.eligibility_id)

            return eligibility

    async def check_eligibility_async(
        self, create_eligibility_request: CreateEligibilityRequest, timeout: int = 60
    ) -> Union[EligibilityApiResponse, None]:
        if not self.websocket_url:
            raise ValueError("This method cannot be called without a websocket URL.")

        response = self.create_eligibility(create_eligibility_request)

        result = None

        async def receive_messages():
            nonlocal result
            async with websockets.connect(self.websocket_url) as ws:
                await ws.send(
                    json.dumps({"card_id": response.card_id, "action": "register"})
                )

                async for message in ws:
                    event = json.loads(message)

                    if event['type'] != 'eligibility':
                        continue

                    if event["state"] == EligibilityState.COMPLETED:
                        result = EligibilityWebsocketEvent.from_dict(event)
                        break
                    elif event["state"] == EligibilityState.ERROR:
                        raise Exception(f"Eligibility check failed: {event['error']}")

        try:
            await asyncio.wait_for(receive_messages(), timeout)
        except asyncio.TimeoutError:
            raise TimeoutError("Operation timed out while waiting for eligibility check to complete.")

        if result:
            eligibility = self.get_eligibility_by_id(result.eligibility_id)
            return eligibility

    async def _check_eligibility(
        self, create_eligibility_request: CreateEligibilityRequest
    ) -> Union[EligibilityApiResponse, None]:
        if not self.websocket_url:
            raise ValueError("This method cannot be called without a websocket URL.")

        response = self.create_eligibility(create_eligibility_request)

        result = None

        async with websockets.connect(self.websocket_url) as ws:
            await ws.send(
                json.dumps({"card_id": response.card_id, "action": "register"})
            )

            async for message in ws:
                event = json.loads(message)

                if event['type'] != 'eligibility':
                    continue

                if event["state"] == EligibilityState.COMPLETED:
                    result = EligibilityWebsocketEvent.from_dict(event)
                    break
                elif event["state"] == EligibilityState.ERROR:
                    raise Exception(f"Eligibility check failed: {event['error']}")

        if result:
            eligibility = self.get_eligibility_by_id(result.eligibility_id)

            return eligibility


    @validate_arguments
    def card_performance(self, card_id : StrictStr, body : Optional[Dict[str, Any]] = None, **kwargs) -> CardPerformance200Response:  # noqa: E501
        """Card - Send performance data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.card_performance(card_id, body, async_req=True)
        >>> result = thread.get()

        :param card_id: (required)
        :type card_id: str
        :param body:
        :type body: object
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardPerformance200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the card_performance_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.card_performance_with_http_info(card_id, body, **kwargs)  # noqa: E501

    @validate_arguments
    def card_performance_with_http_info(self, card_id : StrictStr, body : Optional[Dict[str, Any]] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Card - Send performance data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.card_performance_with_http_info(card_id, body, async_req=True)
        >>> result = thread.get()

        :param card_id: (required)
        :type card_id: str
        :param body:
        :type body: object
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardPerformance200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'card_id',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method card_performance" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['card_id'] is not None:
            _path_params['card_id'] = _params['card_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body'] is not None:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CardPerformance200Response",
            '401': "ApiErrorResponse",
            '403': "ApiErrorResponse",
            '404': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/cards/{card_id}/performance', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_card(self, create_card_request : Optional[CreateCardRequest] = None, **kwargs) -> CardApiResponse:  # noqa: E501
        """Creates a new card  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_card(create_card_request, async_req=True)
        >>> result = thread.get()

        :param create_card_request:
        :type create_card_request: CreateCardRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardApiResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_card_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_card_with_http_info(create_card_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_card_with_http_info(self, create_card_request : Optional[CreateCardRequest] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Creates a new card  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_card_with_http_info(create_card_request, async_req=True)
        >>> result = thread.get()

        :param create_card_request:
        :type create_card_request: CreateCardRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardApiResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'create_card_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_card" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['create_card_request'] is not None:
            _body_params = _params['create_card_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "CardApiResponse",
            '400': "ApiErrorResponse",
            '401': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/cards', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_eligibility(self, create_eligibility_request : Optional[CreateEligibilityRequest] = None, **kwargs) -> EligibilityApiResponse:  # noqa: E501
        """Create Eligibility Record  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_eligibility(create_eligibility_request, async_req=True)
        >>> result = thread.get()

        :param create_eligibility_request:
        :type create_eligibility_request: CreateEligibilityRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: EligibilityApiResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_eligibility_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_eligibility_with_http_info(create_eligibility_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_eligibility_with_http_info(self, create_eligibility_request : Optional[CreateEligibilityRequest] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Create Eligibility Record  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_eligibility_with_http_info(create_eligibility_request, async_req=True)
        >>> result = thread.get()

        :param create_eligibility_request:
        :type create_eligibility_request: CreateEligibilityRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(EligibilityApiResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'create_eligibility_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_eligibility" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['create_eligibility_request'] is not None:
            _body_params = _params['create_eligibility_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "EligibilityApiResponse",
            '400': "ApiErrorResponse",
            '401': "ApiErrorResponse",
            '404': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/eligibility', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_card_by_id(self, card_id : Annotated[StrictStr, Field(..., description="The ID of the card")], **kwargs) -> None:  # noqa: E501
        """Delete Card  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_card_by_id(card_id, async_req=True)
        >>> result = thread.get()

        :param card_id: The ID of the card (required)
        :type card_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the delete_card_by_id_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.delete_card_by_id_with_http_info(card_id, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_card_by_id_with_http_info(self, card_id : Annotated[StrictStr, Field(..., description="The ID of the card")], **kwargs) -> ApiResponse:  # noqa: E501
        """Delete Card  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_card_by_id_with_http_info(card_id, async_req=True)
        >>> result = thread.get()

        :param card_id: The ID of the card (required)
        :type card_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'card_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_card_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['card_id'] is not None:
            _path_params['card_id'] = _params['card_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/cards/{card_id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def direct_upload(self, orientation : ScanOrientation, capture_type : ScanCaptureType, card_id : StrictStr, direct_upload_request : Optional[DirectUploadRequest] = None, **kwargs) -> DirectUpload200Response:  # noqa: E501
        """Direct Upload  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.direct_upload(orientation, capture_type, card_id, direct_upload_request, async_req=True)
        >>> result = thread.get()

        :param orientation: (required)
        :type orientation: ScanOrientation
        :param capture_type: (required)
        :type capture_type: ScanCaptureType
        :param card_id: (required)
        :type card_id: str
        :param direct_upload_request:
        :type direct_upload_request: DirectUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DirectUpload200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the direct_upload_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.direct_upload_with_http_info(orientation, capture_type, card_id, direct_upload_request, **kwargs)  # noqa: E501

    @validate_arguments
    def direct_upload_with_http_info(self, orientation : ScanOrientation, capture_type : ScanCaptureType, card_id : StrictStr, direct_upload_request : Optional[DirectUploadRequest] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Direct Upload  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.direct_upload_with_http_info(orientation, capture_type, card_id, direct_upload_request, async_req=True)
        >>> result = thread.get()

        :param orientation: (required)
        :type orientation: ScanOrientation
        :param capture_type: (required)
        :type capture_type: ScanCaptureType
        :param card_id: (required)
        :type card_id: str
        :param direct_upload_request:
        :type direct_upload_request: DirectUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DirectUpload200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'orientation',
            'capture_type',
            'card_id',
            'direct_upload_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method direct_upload" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['card_id'] is not None:
            _path_params['card_id'] = _params['card_id']


        # process the query parameters
        _query_params = []
        if _params.get('orientation') is not None:  # noqa: E501
            _query_params.append(('orientation', _params['orientation'].value))

        if _params.get('capture_type') is not None:  # noqa: E501
            _query_params.append(('capture_type', _params['capture_type'].value))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['direct_upload_request'] is not None:
            _body_params = _params['direct_upload_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['image/jpeg']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "DirectUpload200Response",
            '400': "ApiErrorResponse",
            '401': "ApiErrorResponse",
            '403': "ApiErrorResponse",
            '404': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/cards/{card_id}/upload', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def generate_card_upload_url(self, card_id : StrictStr, expiration : Optional[conint(strict=True, le=3600, ge=100)] = None, generate_card_upload_url_request : Optional[GenerateCardUploadUrlRequest] = None, **kwargs) -> GenerateCardUploadUrl200Response:  # noqa: E501
        """Card - Generate Upload URL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_card_upload_url(card_id, expiration, generate_card_upload_url_request, async_req=True)
        >>> result = thread.get()

        :param card_id: (required)
        :type card_id: str
        :param expiration:
        :type expiration: int
        :param generate_card_upload_url_request:
        :type generate_card_upload_url_request: GenerateCardUploadUrlRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GenerateCardUploadUrl200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the generate_card_upload_url_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.generate_card_upload_url_with_http_info(card_id, expiration, generate_card_upload_url_request, **kwargs)  # noqa: E501

    @validate_arguments
    def generate_card_upload_url_with_http_info(self, card_id : StrictStr, expiration : Optional[conint(strict=True, le=3600, ge=100)] = None, generate_card_upload_url_request : Optional[GenerateCardUploadUrlRequest] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Card - Generate Upload URL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_card_upload_url_with_http_info(card_id, expiration, generate_card_upload_url_request, async_req=True)
        >>> result = thread.get()

        :param card_id: (required)
        :type card_id: str
        :param expiration:
        :type expiration: int
        :param generate_card_upload_url_request:
        :type generate_card_upload_url_request: GenerateCardUploadUrlRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GenerateCardUploadUrl200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'card_id',
            'expiration',
            'generate_card_upload_url_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_card_upload_url" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['card_id'] is not None:
            _path_params['card_id'] = _params['card_id']


        # process the query parameters
        _query_params = []
        if _params.get('expiration') is not None:  # noqa: E501
            _query_params.append(('expiration', _params['expiration']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['generate_card_upload_url_request'] is not None:
            _body_params = _params['generate_card_upload_url_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "GenerateCardUploadUrl200Response",
            '400': "ApiErrorResponse",
            '401': "ApiErrorResponse",
            '403': "ApiErrorResponse",
            '404': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/cards/{card_id}/generate-upload-url', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def generate_magic_link(self, **kwargs) -> GenerateMagicLink200Response:  # noqa: E501
        """Generate Magic Link  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_magic_link(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GenerateMagicLink200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the generate_magic_link_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.generate_magic_link_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def generate_magic_link_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """Generate Magic Link  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_magic_link_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GenerateMagicLink200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_magic_link" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "GenerateMagicLink200Response",
            '401': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/generate-magic-link', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def generate_upload_url(self, expiration : conint(strict=True, le=3600, ge=100), **kwargs) -> GenerateCardUploadUrl200Response:  # noqa: E501
        """Generate an upload URL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_upload_url(expiration, async_req=True)
        >>> result = thread.get()

        :param expiration: (required)
        :type expiration: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GenerateCardUploadUrl200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the generate_upload_url_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.generate_upload_url_with_http_info(expiration, **kwargs)  # noqa: E501

    @validate_arguments
    def generate_upload_url_with_http_info(self, expiration : conint(strict=True, le=3600, ge=100), **kwargs) -> ApiResponse:  # noqa: E501
        """Generate an upload URL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_upload_url_with_http_info(expiration, async_req=True)
        >>> result = thread.get()

        :param expiration: (required)
        :type expiration: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GenerateCardUploadUrl200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'expiration'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_upload_url" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('expiration') is not None:  # noqa: E501
            _query_params.append(('expiration', _params['expiration']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "GenerateCardUploadUrl200Response",
            '400': "ApiErrorResponse",
            '401': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/generate-upload-url', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_access_token(self, user_id : Annotated[Optional[StrictStr], Field(description="The ID of the user")] = None, **kwargs) -> GetAccessToken200Response:  # noqa: E501
        """Access Token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_access_token(user_id, async_req=True)
        >>> result = thread.get()

        :param user_id: The ID of the user
        :type user_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetAccessToken200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_access_token_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_access_token_with_http_info(user_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_access_token_with_http_info(self, user_id : Annotated[Optional[StrictStr], Field(description="The ID of the user")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Access Token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_access_token_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param user_id: The ID of the user
        :type user_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetAccessToken200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'user_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_access_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('user_id') is not None:  # noqa: E501
            _query_params.append(('user_id', _params['user_id']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "GetAccessToken200Response",
            '401': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/access-token', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_card_by_id(self, card_id : Annotated[StrictStr, Field(..., description="The ID of the card")], **kwargs) -> CardApiResponse:  # noqa: E501
        """Get Card by ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_card_by_id(card_id, async_req=True)
        >>> result = thread.get()

        :param card_id: The ID of the card (required)
        :type card_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardApiResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_card_by_id_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_card_by_id_with_http_info(card_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_card_by_id_with_http_info(self, card_id : Annotated[StrictStr, Field(..., description="The ID of the card")], **kwargs) -> ApiResponse:  # noqa: E501
        """Get Card by ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_card_by_id_with_http_info(card_id, async_req=True)
        >>> result = thread.get()

        :param card_id: The ID of the card (required)
        :type card_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardApiResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'card_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_card_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['card_id'] is not None:
            _path_params['card_id'] = _params['card_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CardApiResponse",
            '401': "ApiErrorResponse",
            '403': "ApiErrorResponse",
            '404': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/cards/{card_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_eligibility_by_id(self, eligibility_id : StrictStr, **kwargs) -> EligibilityApiResponse:  # noqa: E501
        """Get Eligibility  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_eligibility_by_id(eligibility_id, async_req=True)
        >>> result = thread.get()

        :param eligibility_id: (required)
        :type eligibility_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: EligibilityApiResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_eligibility_by_id_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_eligibility_by_id_with_http_info(eligibility_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_eligibility_by_id_with_http_info(self, eligibility_id : StrictStr, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Eligibility  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_eligibility_by_id_with_http_info(eligibility_id, async_req=True)
        >>> result = thread.get()

        :param eligibility_id: (required)
        :type eligibility_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(EligibilityApiResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'eligibility_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_eligibility_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['eligibility_id'] is not None:
            _path_params['eligibility_id'] = _params['eligibility_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "EligibilityApiResponse",
            '400': "ApiErrorResponse",
            '401': "ApiErrorResponse",
            '404': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/eligibility/{eligibility_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_cards(self, limit : Optional[StrictInt] = None, cursor : Optional[StrictStr] = None, **kwargs) -> SearchCards200Response:  # noqa: E501
        """List Cards  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_cards(limit, cursor, async_req=True)
        >>> result = thread.get()

        :param limit:
        :type limit: int
        :param cursor:
        :type cursor: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SearchCards200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the list_cards_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.list_cards_with_http_info(limit, cursor, **kwargs)  # noqa: E501

    @validate_arguments
    def list_cards_with_http_info(self, limit : Optional[StrictInt] = None, cursor : Optional[StrictStr] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """List Cards  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_cards_with_http_info(limit, cursor, async_req=True)
        >>> result = thread.get()

        :param limit:
        :type limit: int
        :param cursor:
        :type cursor: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SearchCards200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'cursor'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_cards" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('cursor') is not None:  # noqa: E501
            _query_params.append(('cursor', _params['cursor']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "SearchCards200Response",
            '401': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/cards', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_eligibility(self, limit : Optional[StrictInt] = None, cursor : Optional[StrictStr] = None, **kwargs) -> ListEligibility200Response:  # noqa: E501
        """List Eligibility  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_eligibility(limit, cursor, async_req=True)
        >>> result = thread.get()

        :param limit:
        :type limit: int
        :param cursor:
        :type cursor: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListEligibility200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the list_eligibility_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.list_eligibility_with_http_info(limit, cursor, **kwargs)  # noqa: E501

    @validate_arguments
    def list_eligibility_with_http_info(self, limit : Optional[StrictInt] = None, cursor : Optional[StrictStr] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """List Eligibility  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_eligibility_with_http_info(limit, cursor, async_req=True)
        >>> result = thread.get()

        :param limit:
        :type limit: int
        :param cursor:
        :type cursor: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListEligibility200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'cursor'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_eligibility" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('cursor') is not None:  # noqa: E501
            _query_params.append(('cursor', _params['cursor']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "ListEligibility200Response",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/eligibility', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def search_cards(self, query : StrictStr, limit : Optional[StrictInt] = None, cursor : Optional[StrictStr] = None, **kwargs) -> SearchCards200Response:  # noqa: E501
        """Search Cards (200) OK  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search_cards(query, limit, cursor, async_req=True)
        >>> result = thread.get()

        :param query: (required)
        :type query: str
        :param limit:
        :type limit: int
        :param cursor:
        :type cursor: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SearchCards200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the search_cards_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.search_cards_with_http_info(query, limit, cursor, **kwargs)  # noqa: E501

    @validate_arguments
    def search_cards_with_http_info(self, query : StrictStr, limit : Optional[StrictInt] = None, cursor : Optional[StrictStr] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Search Cards (200) OK  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search_cards_with_http_info(query, limit, cursor, async_req=True)
        >>> result = thread.get()

        :param query: (required)
        :type query: str
        :param limit:
        :type limit: int
        :param cursor:
        :type cursor: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SearchCards200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'query',
            'limit',
            'cursor'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_cards" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('query') is not None:  # noqa: E501
            _query_params.append(('query', _params['query']))

        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('cursor') is not None:  # noqa: E501
            _query_params.append(('cursor', _params['cursor']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "SearchCards200Response",
            '401': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/cards/search', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def set_scan_metadata(self, scan_id : StrictStr, body : Optional[Dict[str, Any]] = None, **kwargs) -> None:  # noqa: E501
        """Set Scan Metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_scan_metadata(scan_id, body, async_req=True)
        >>> result = thread.get()

        :param scan_id: (required)
        :type scan_id: str
        :param body:
        :type body: object
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the set_scan_metadata_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.set_scan_metadata_with_http_info(scan_id, body, **kwargs)  # noqa: E501

    @validate_arguments
    def set_scan_metadata_with_http_info(self, scan_id : StrictStr, body : Optional[Dict[str, Any]] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Set Scan Metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_scan_metadata_with_http_info(scan_id, body, async_req=True)
        >>> result = thread.get()

        :param scan_id: (required)
        :type scan_id: str
        :param body:
        :type body: object
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'scan_id',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_scan_metadata" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['scan_id'] is not None:
            _path_params['scan_id'] = _params['scan_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body'] is not None:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/scans/{scan_id}/metadata', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def validate_magic_link(self, token : StrictStr, **kwargs) -> ValidateMagicLink200Response:  # noqa: E501
        """Validate Magic Link  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.validate_magic_link(token, async_req=True)
        >>> result = thread.get()

        :param token: (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ValidateMagicLink200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the validate_magic_link_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.validate_magic_link_with_http_info(token, **kwargs)  # noqa: E501

    @validate_arguments
    def validate_magic_link_with_http_info(self, token : StrictStr, **kwargs) -> ApiResponse:  # noqa: E501
        """Validate Magic Link  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.validate_magic_link_with_http_info(token, async_req=True)
        >>> result = thread.get()

        :param token: (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ValidateMagicLink200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_magic_link" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('token') is not None:  # noqa: E501
            _query_params.append(('token', _params['token']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "ValidateMagicLink200Response",
            '400': "ApiErrorResponse",
            '404': "ApiErrorResponse",
            '410': "ApiErrorResponse",
            '500': "GetAccessToken500Response",
        }

        return self.api_client.call_api(
            '/validate-magic-link', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ScanCaptureType(str, Enum):
    """
    ScanCaptureType
    """

    """
    allowed enum values
    """
    MANUAL = 'manual'
    AUTOMATIC = 'automatic'
    SELECTEDFILE = 'selectedFile'
    API = 'api'

    @classmethod
    def from_json(cls, json_str: str) -> ScanCaptureType:
        """Create an instance of ScanCaptureType from a JSON string"""
        return ScanCaptureType(json.loads(json_str))


